<?php
/**
 * Template Name: Our Story Template
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */
get_header();

$options = tp_philosophy_pro_get_theme_options(); // get theme options

$enable_mission         = isset( $options['story_template_mission_enable'] ) ? $options['story_template_mission_enable'] : false;
$mission_section_title  = ! empty( $options['story_template_mission_section_title'] ) ? $options['story_template_mission_section_title'] : esc_html__( 'Mission', 'tp-philosophy-pro' );

$enable_services        =  isset( $options['story_template_services_enable'] ) ? $options['story_template_services_enable'] : false;
$services_section_title = ! empty( $options['story_template_service_section_title'] ) ? $options['story_template_service_section_title'] : esc_html__( 'Our Services', 'tp-philosophy-pro' );

$enable_quote           = isset( $options['story_template_quote_enable'] ) ? $options['story_template_quote_enable'] : false;
$quote_section_title    = ! empty( $options['story_template_quote_section_title'] ) ? $options['story_template_quote_section_title'] : esc_html__( 'Quote', 'tp-philosophy-pro' );

$enable_team            = isset( $options['story_template_team_enable'] ) ? $options['story_template_team_enable'] : false;
$team_section_title     = ! empty( $options['story_template_team_section_title'] ) ? $options['story_template_team_section_title'] : esc_html__( 'The Team', 'tp-philosophy-pro' );

$heading_box_layout     = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border' : '';


?>
    <nav class="section-navigation">
        <div class="wrapper">
            <ul>
                <?php 
                    if( $enable_mission ){
                        echo '<li class="active"><a href="#our-mission" class="scroll-link">'. esc_html( $mission_section_title ) .'</a></li>';
                    }

                    if( $enable_services ){
                        echo '<li><a href="#prime-services" class="scroll-link">'. esc_html( $services_section_title ) .'</a></li>';
                    }

                    if( $enable_quote ){
                        echo '<li><a href="#chat" class="scroll-link">'. esc_html( $quote_section_title ) .'</a></li>';
                    }

                    if( $enable_team ){
                        echo '<li><a href="#teams" class="scroll-link">'. esc_html( $team_section_title ) .'</a></li>';
                    }
                ?>
            </ul>
        </div><!--.wrapper-->
    </nav><!--.navigation-->

    <?php 
        if ( $enable_mission ) :
            $mission_section_title = ! empty( $options['story_template_mission_section_title'] ) ? $options['story_template_mission_section_title'] : 'mission';

            $mission_title = ! empty( $options['story_template_mission_title'] ) ? $options['story_template_mission_title'] : '';

            $mission_description = ! empty( $options['story_template_mission_description'] ) ? $options['story_template_mission_description'] : '';

            $mission_content_type = !empty( $options['story_template_mission_content_type'] ) ? $options['story_template_mission_content_type'] : 'post';

            switch ( $mission_content_type ) {
                case 'post':
                    $featured_content_ids = !empty( $options['story_template_mission_posts_ids'] ) ? $options['story_template_mission_posts_ids'] : array();
                    break;

                case 'page':
                    $featured_content_ids = array();
                    for ( $i=1; $i<=4; $i++ ){
                        if( !empty( $options['story_template_mission_page_id_'. $i ] ) ) {
                            $featured_content_ids = array_merge( $featured_content_ids , array( $options['story_template_mission_page_id_'. $i ] ) );
                        }
                    }
                    break;
                
                default:
                    # code...
                    break;
            }

            $section_class = ( ! empty( $featured_content_ids ) ) ? 'col-2' : 'col-1';

            $header_class = ( 'col-1' == $section_class ) ? 'entry-header text-center '. esc_attr( $heading_box_layout ) .' border-center' : 'entry-header '. esc_attr( $heading_box_layout ) .' border-small';
    ?>
        <section id="our-mission" class="page-section <?php echo esc_attr( $section_class ); ?>">
          <div class="wrapper">
            <div class="column-wrapper">

                <?php 
                    if( ! empty( $mission_title ) ) : ?>
                        <header class="<?php echo esc_attr( $header_class ); ?>">
                            <h2 class="entry-title"><?php echo wp_kses_post( $mission_title ); ?></h2>
                        </header><!--.entry-header-->
                <?php 
                    endif; 

                    if ( !empty( $mission_description ) ) : ?>
                        <div class="entry-content">
                            <?php echo '<p>'. wp_kses_post( $mission_description ) .'<p>'; ?>
                        </div><!--.entry-content-->
                <?php
                    endif;

                ?>
            </div><!--.column-wrapper-->

            <?php 
                if ( !empty( $featured_content_ids ) ) :
                    $mission_args = array(
                        'post_type'      => $mission_content_type,
                        'post__in'       => $featured_content_ids,
                        'orderby'        => 'post__in',
                        'posts_per_page' => 4,
                    );

                    $featured_posts = get_posts( $mission_args );

                    if ( !empty( $featured_posts ) ) : 
             ?>
                <div class="column-wrapper">
                    <div class="mission col-2">
                    <?php 
                        foreach ( $featured_posts as $featured_post ) {
                            $mission_post_id = $featured_post->ID;
                            $thumbnail_img = array();

                            if( has_post_thumbnail( $mission_post_id ) ){
                                $thumbnail_img = wp_get_attachment_image_src( get_post_thumbnail_id( $mission_post_id ), 'tp-philosophy-pro-square-thumbnail' );
                            } else {
                                $thumbnail_img[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                            }   

                            $mission_url    = get_permalink( $mission_post_id );
                            $mission_title  = get_the_title( $mission_post_id ); 
                    ?>
                        <div class="column-wrapper">
                            <div class="row">
                                <div class="featured-image">
                                    <img src="<?php echo esc_url( $thumbnail_img[0] ); ?>" alt="<?php echo esc_html( $mission_title ); ?>">
                                    <div class="blue-overlay"></div>
                                    <div class="hover-content">
                                        <h4><?php echo esc_html( $mission_title ); ?></h4>
                                        <a href="<?php echo esc_url( $mission_url ); ?>" class="view-more hover-white"><span data-hover="<?php esc_attr_e( "Detail", "tp-philosophy-pro" ); ?>"><?php esc_html_e( "Detail", "tp-philosophy-pro" ); ?></span></a>
                                    </div><!--.hover-content-->
                                </div><!--.featured-image-->
                            </div><!--.row-->
                        </div><!--.column-wrapper-->
                    <?php } endif; ?>

            
                    </div><!--.col-2-->
                </div><!--.column-wrapper-->
            <?php endif; ?>
          </div><!--wrapper-->
        </section><!--#our-mission-->
    <?php endif; ?>

    <?php
        if ( $enable_services ) :

            $background_image = ! empty( $options['story_template_service_section_image'] ) ? $options['story_template_service_section_image'] : '';

            $column_layout = ! empty( $options['story_template_column_layout'] ) ? $options['story_template_column_layout'] : 4;

            switch ( $column_layout ) {
                case '3':
                    $section_class = 'col-3';
                    break;
                case '4':
                    $section_class = 'col-4';
                    break;
                case '5':
                    $section_class = 'col-5';
                    break;

                default:
                    $section_class = 'col-4';
                    break;
            }

            if ( !empty( $background_image ) ) {
                $services_background_style = "style='background-image: url(".esc_url( $background_image ) .");'";
            } else {
                $services_background_style = '';
            }
    ?>
    <section id="prime-services" class="page-section" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="-500" <?php echo $services_background_style; ?>>
        <div class="black-overlay"></div>
        <div class="wrapper">
            <div class="prime-content <?php echo esc_attr( $section_class ); ?>">

                <?php 
                    for( $i=1; $i<= $column_layout; $i++ ) {
                        $service_icon = ! empty( $options['story_template_service_icon_' .$i ] ) ? $options['story_template_service_icon_' .$i ] : '';
                        $service_text = ! empty( $options['story_template_service_text_' .$i ] ) ? $options['story_template_service_text_' .$i ] : '';

                        if( !empty( $service_icon || $service_text ) ) { 
                    ?>
                    <div class="column-wrapper">
                      <div class="statwrap">
                        <?php 
                            if( !empty( $service_icon ) ){
                                echo '<i class="fa '. esc_attr( $service_icon ) .'"></i>';
                            }

                            if( !empty( $service_text ) ){
                                echo '<small>'. esc_html( $service_text ) .'</small>';
                            }
                        ?>
                      </div><!-- .statwrap -->
                    </div><!--.column-wrapper-->
                <?php }
                    } ?>
                
            </div><!--.prime-content-->
        </div><!--.wrapper-->
    </section><!--#prime-services-->
    <?php endif; ?>

    <?php 
        if ( $enable_quote ) :
            $quote_title = ! empty( $options['story_template_quote_title'] ) ? $options['story_template_quote_title'] : '';
            $quote_text =  ! empty( $options['story_template_quote_text'] ) ? $options['story_template_quote_text'] : '';
        ?>
        <section id="chat" class="page-section">
            <div class="wrapper">
                <div class="chat-wrapper">
                    <?php if ( !empty( $quote_title ) ) : ?>
                        <header class="entry-header">
                            <?php echo wp_kses_post( $quote_title ); ?>
                        </header><!--.entry-header-->
                    <?php endif; ?>

                    <?php if ( !empty( $quote_text ) ) : ?>
                        <div class="entry-content">
                            <?php echo wp_kses_post( $quote_text ); ?>
                        </div><!--.entry-content-->
                    <?php endif; ?>
                </div><!--.team-wrapper-->
            </div><!--.wrapper-->
        </section><!--#the-team-->
    <?php endif; ?>

    <?php if ( $enable_team ) : ?>
        <section id="teams" class="the-team page-section">
            <div class="wrapper">
                <?php 
                    $team_section_title = ! empty( $options['story_template_team_section_title'] ) ? $options['story_template_team_section_title'] : esc_html__( 'Our Team', 'tp-philosophy-pro' );
                    $team_title         =  ! empty( $options['story_template_work_title'] ) ? $options['story_template_work_title'] : '';
                    $team_description   =  ! empty( $options['story_template_work_description'] ) ? $options['story_template_work_description'] : '';

                    $team_content_type = ! empty( $options['story_template_team_content_type'] ) ? $options['story_template_team_content_type'] : 'post'; 

                    if( ! empty( $team_title ) || ! empty( $team_description ) ) :
                        echo '<header class="entry-header '. esc_attr( $heading_box_layout ) .' border-small border-center">';

                        echo wp_kses_post( $team_title );
                        if ( ! empty( $team_description ) ) {
                            echo '<p>'. wp_kses_post( $team_description ) .'</p>';
                        }
                        echo '</header><!-- entry-header -->';
                    endif;

                    $team_content = array();

                    switch ( $team_content_type ) {
                        case 'post':
                            $team_ids = !empty( $options['story_template_team_default_posts_ids'] ) ?  $options['story_template_team_default_posts_ids'] : array();

                            if ( !empty( $team_ids ) ){
                                $team_args = array(
                                    'post_type'      => 'post',
                                    'post__in'       => $team_ids,
                                    'orderby'        => 'post__in',
                                    'posts_per_page' => 3
                                );

                                // Get team posts
                                $team_content = get_posts( $team_args );
                            }


                        break;

                        case 'tp-philosophy-teams':
                            $team_ids = !empty( $options['story_template_team_plugin_posts_ids'] ) ?  $options['story_template_team_plugin_posts_ids'] : array();

                            if ( ! empty( $team_ids ) ){
                                $team_args = array(
                                    'post_type'      => 'tp-philosophy-teams',
                                    'post__in'       => $team_ids,
                                    'orderby'        => 'post__in',
                                    'posts_per_page' => 3
                                );

                                // Get team posts
                                $team_content = get_posts( $team_args );
                            }


                        break;
                        
                        default:
                            # code...
                        break;
                    }
                ?>

                <?php   if ( ! empty( $team_content ) ) :  ?>
                <div class="entry-content col-3">
                    <?php 
                        foreach ( $team_content as $team_member ) {
                            $member_id = $team_member->ID;

                            $img_array = array();

                            if ( has_post_thumbnail( $member_id ) ) {
                                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $member_id ), 'tp-philosophy-pro-square-thumbnail' );
                            } else {
                                $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                            }
                        ?>
                        <div class="column-wrapper">
                            <a href="<?php echo esc_url( get_permalink( $member_id ) ); ?>"><img src="<?php echo esc_url( $img_array[0] ); ?>" alt="<?php echo esc_html( get_the_title( $member_id ) ); ?>"></a>
                        </div><!-- .team-member -->
                    <?php } ?>
                    
                </div><!--.entry-content-->
                <?php 
                    $team_load_more_text = ! empty( $options['story_template_team_view_more_text'] ) ? $options['story_template_team_view_more_text'] : '';
                    $team_archive_link   = !empty( $options['story_template_view_teams_link'] ) ? $options['story_template_view_teams_link'] : '#';

                    if( !empty( $team_load_more_text ) ) {
                        echo '<a href="'. esc_url( $team_archive_link ).'" class="view-more hover-white"><span data-hover="'. esc_attr( $team_load_more_text ) .'">'. esc_html( $team_load_more_text ) .'</span></a>';
                    }

                endif; ?>
            </div><!-- .wrapper -->
        </section><!-- .the-team-->
    <?php endif; ?>
<?php
get_footer();