<?php
    /**
     * Template Name: Our Team Template
     *
     * @package Theme_Palace
     * @subpackage TP_Philosophy_Pro
     * @since 1.0
     */
    get_header();

    if( ! function_exists( 'tp_philosophy_pro_filter_get_team_options' ) ) :
        /**
        * Add team options filter
        *
        * @since 1.0
        */
        function tp_philosophy_pro_filter_get_team_options( $input ) {
            $options      = tp_philosophy_pro_get_theme_options(); // get theme options
            $content_type = $options['team_options_content_type'];
            $content      = array(); // create an empty array
            
            switch ( $content_type ) {
                case 'category':
                    $category_ids = ! empty( $options['team_options_content_category'] ) ? ( array ) $options['team_options_content_category'] : array();

                    // Bial if no category is selected
                    if ( empty( $category_ids ) ) {
                        return;
                    }

                    $args = array( 
                        'category__in'   => $category_ids,
                        'posts_per_page' => 12,
                    );

                    $team_posts = get_posts( $args );

                    $i = 1;
                    foreach( $team_posts as $team_member ){

                        $member_id   = $team_member->ID;
                        $img_array = array();

                        if ( has_post_thumbnail( $member_id ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $member_id ), 'tp-philosophy-pro-square-thumbnail' );
                        }  else {
                            $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                        }   

                        $content[$i]['member_id'] = $member_id;
                        $content[$i]['img_array'] = $img_array;
                        $content[$i]['url']       = get_permalink( $member_id );
                        $content[$i]['title']     = get_the_title( $member_id );
                        $content[$i]['description'] = '';


                        $i++;     
                    }
                    break;
                
                case 'tp-philosophy-teams' :
                     $team_category_ids = ! empty( $options['team_options_custom_taxonomy'] ) ? $options['team_options_custom_taxonomy'] : array();

                    // Bial if no category is selected
                    if ( empty( $team_category_ids ) ) {
                        return;
                    }

                    $team_args = array(
                        'post_type'      => 'tp-philosophy-teams',
                        'posts_per_page' => 12,
                        'tax_query' => array(
                            array(
                                'taxonomy' => 'tp-philosophy-teams-category',
                                'field'    => 'ID',
                                'terms'    => $team_category_ids,
                            )
                        )
                    );

                    $team_posts = get_posts( $team_args );

                    $i = 1;
                    foreach( $team_posts as $team_member ){

                        $member_id   = $team_member->ID;
                        $img_array = array();

                        if ( has_post_thumbnail( $member_id ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $member_id ), 'tp-philosophy-pro-square-thumbnail' );
                        }  else {
                            $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.jpg';
                        }   

						$content[$i]['img_array']   = $img_array;
						$content[$i]['member_id']   = $member_id;
						$content[$i]['url']         = get_permalink( $member_id );
						$content[$i]['title']       = get_the_title( $member_id );
						$content[$i]['description'] = $team_member->post_content;

                        $i++;     
                    }
                    break;

                default :
                    break;
            }

            if( ! empty( $content ) ) {
            	$input = $content;
            }

            return $input;
        }
    endif;
    add_filter ( 'tp_philosophy_pro_filter_team_options', 'tp_philosophy_pro_filter_get_team_options' );

    if( ! function_exists( 'tp_philosophy_pro_render_team_options' ) ) :
    	/**
    	 * Render team options 
    	 * 
    	 * @since 1.0
    	 */

    	function tp_philosophy_pro_render_team_options() {
    		$options = tp_philosophy_pro_get_theme_options(); // get theme options

    		$content_type = $options['team_options_content_type'];
    		$enable_team_options = isset( $options['enable_team_options'] ) ? $options['enable_team_options'] : false;

		    if( false == $enable_team_options ) {
		    	return false;
		    }

           	$team_title       = ! empty( $options['team_options_custom_title'] ) ? $options['team_options_custom_title'] : '';
            $team_subtitle    = ! empty( $options['team_options_subtitle'] ) ? $options['team_options_subtitle'] : '';
            $team_description = ! empty( $options['team_options_custom_description'] ) ? $options['team_options_custom_description'] : '';


            $heading_box_layout     = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border' : '';

            $team_class = '';

            if( class_exists( 'TP_Philosophy_Tools') && 'tp-philosophy-teams' == $content_type ) {
            	$team_class = 'pop-up';
            }
    		?>

	    	<section id="teams" class="page-section <?php echo esc_attr( $team_class );?>">
	        	<div class="wrapper">
		            <header class="entry-header <?php echo esc_attr( $heading_box_layout ); ?> border-small border-center">
		                <?php 
		                    if ( ! empty( $team_title ) ){
		                        echo ' <h2 class="entry-title color-white">'. esc_html( $team_title ) .'</h2>';
		                    }

		                    if ( ! empty( $team_subtitle ) ){
		                        echo '<h3 class="sub-title">'. esc_html( $team_subtitle ) .'</h3>';
		                    }

		                    if ( ! empty( $team_description ) ){
		                        echo '<p>'. esc_html( $team_description ) .'</p>';
		                    }
		                ?>
		            </header><!-- entry-header -->
		            <?php 
		            	$content_detail = array();
		           		$content_detail = apply_filters( 'tp_philosophy_pro_filter_team_options', $content_detail ); 

		           		if ( empty( $content_detail ) ) {
                            return;
                        } 
		            ?>
			          	<div class="entry-content col-4">

			          		<i class="fa fa-times"></i>
			          		<?php 
			          			foreach ( $content_detail as $content ) { 
			          				$image_source = '<a href="'. esc_url( $content['url'] ) .'"><img src="'. esc_url( $content['img_array'][0] ) .'" alt="'. esc_attr( $content['title'] ) .'"></a>';
            
						            if( class_exists( 'TP_Philosophy_Tools') && 'tp-philosophy-teams' == $content_type ) {
						            	$image_source = '<img src="'. esc_url( $content['img_array'][0] ) .'" alt="'. esc_attr( $content['title'] ) .'">';
						            }
			          		?>

					            <div class="column-wrapper">
					              	<div class="featured-image">
			                            <?php echo wp_kses_post( $image_source ); ?>
			                            <div class="team-content">
				                            <?php 
				                              if( class_exists( 'TP_Philosophy_Tools') && 'tp-philosophy-teams' == $content_type ) {
                                                echo '<span>';
				                                tp_philosophy_tools_team_designation( $content['member_id'] );
                                                echo '</span>';
				                            	}
				                            ?>
	                                		<span class="team-member-name"><?php echo esc_html( $content['title'] ); ?></span>
                            			</div><!-- .team-content -->
                          			</div><!-- .featured-image -->
                          			<?php  if( class_exists( 'TP_Philosophy_Tools') && 'tp-philosophy-teams' == $content_type ) { ?>
							            <div class="team-popup col-2">
							                <div class="row">
								                <div class="column-wrapper">
								                  	<div class="developer">
								                    	<img src="<?php echo esc_url( $content['img_array'][0] ); ?>">
								                    	<span class="client-name"><?php echo esc_html( $content['title'] ); ?></span>
								                    	<?php 
								                    		$designation = get_post_meta( $content['member_id'], 'tp_philosophy_team_designation_value', true );
								                    		$designation = ! empty( $designation ) ? $designation : '';

								                    		if( !empty( $designation ) ) {
								                    			echo '<span class="client-position">'. esc_html( $designation ) .'</span>';
								                    		}
								                    	?>
								                    	
								                  	</div><!-- .developer -->
                                                    <?php if ( function_exists( 'tp_philosophy_tools_team_skills_details' ) ) : ?>
    								                  	<div class="team-member-progress">
    									                    <?php tp_philosophy_tools_team_skills_details( $content['member_id'] ); // get skills content ?>
    								                  	</div><!-- .team-member-progress -->
                                                    <?php endif; 
                                                    if ( function_exists( 'tp_philosophy_tools_team_social_links' ) ) : ?>
    								                  	<ul class="social-icon">
    								                    	<?php tp_philosophy_tools_team_social_links( $content['member_id'] ); ?>
    								                  	</ul>
                                                    <?php endif; ?>
								                </div><!-- .column-wrapper -->

								                <div class="column-wrapper">
                                                    <h2><?php esc_html_e( 'About Me', 'tp-philosophy-pro' ); ?></h2>
								                  	<?php 
								                  		echo wp_kses_post( $content['description'] );
													?>
								                </div><!-- .column-wrapper -->
							                </div><!-- .row -->
							            </div><!-- .team-popup -->
							        <?php } ?>
					            </div><!-- .column-wrapper -->
				           	<?php } ?>

			          	</div><!--.entry-content-->
	        	</div><!--. wrapper -->
	      	</section><!-- #team -->
		<?php 
    	} 
	endif;
	add_action( 'tp_philosophy_pro_teams_options', 'tp_philosophy_pro_render_team_options', 10 );

	if( ! function_exists( 'tp_philosophy_pro_filter_get_join_team_options' ) ) :
        /**
        * Add join team options filter
        *
        * @since 1.0
        */
        function tp_philosophy_pro_filter_get_join_team_options( $input ) {
            $options      = tp_philosophy_pro_get_theme_options(); // get theme options
            $content_type = $options['join_team_content_type'];
            $content      = array(); // create an empty array


			$join_team_title       = ! empty( $options['join_team_custom_title'] ) ? $options['join_team_custom_title'] : '';
			$join_team_subtitle    = ! empty( $options['join_team_subtitle'] ) ? $options['join_team_subtitle'] : '';
			$join_team_description = ! empty( $options['join_team_custom_description'] ) ? $options['join_team_custom_description'] : '';
			$join_team_blockquote  = ! empty( $options['join_team_custom_blogquote'] ) ? $options['join_team_custom_blogquote'] : '';
			$join_background_image = ! empty( $options['join_team_custom_image'] ) ? $options['join_team_custom_image'] : '';
			$join_custom_url       = ! empty( $options['join_team_custom_link'] ) ? $options['join_team_custom_link'] : '#';

            
            switch ( $content_type ) {
                case 'post':
                    $join_post_id = ! empty( $options['join_team_post_id'] ) ? $options['join_team_post_id'] : array();

                    // Bial if no post id is selected
                    if ( empty( $join_post_id ) ) {
                        return;
                    }

                    $join_post = get_post( $join_post_id );

                    if ( ! empty( $join_post ) ) {
	                    $post_id   = $join_post->ID;
	                    $img_array = array();

	                    if ( has_post_thumbnail( $post_id ) ) {
	                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'tp-philosophy-pro-about-thumbnail' );
	                    }  else {
	                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x515.jpg';
	                    }   

						$content['img_array']   = $img_array;
						$content['url']         = get_permalink( $post_id );
						$content['title']       = get_the_title( $post_id );
						$content['subtitle'] 	= $join_team_subtitle;
						$content['description'] = tp_philosophy_pro_trim_content( 65, $join_post );
						$content['blockquote']  = $join_team_blockquote;
	                }
                    break;
                
                case 'page' :
                      $join_page_id = ! empty( $options['join_team_page_id'] ) ? $options['join_team_page_id'] : array();

                    // Bial if no post id is selected
                    if ( empty( $join_page_id ) ) {
                        return;
                    }

                    $join_page = get_post( $join_page_id );

                    if ( ! empty( $join_page ) ) {
	                    $page_id   = $join_page->ID;
	                    $img_array = array();

	                    if ( has_post_thumbnail( $page_id ) ) {
	                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'tp-philosophy-pro-about-thumbnail' );
	                    }  else {
	                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x515.jpg';
	                    }   

						$content['img_array']   = $img_array;
						$content['url']         = get_permalink( $page_id );
						$content['title']       = get_the_title( $page_id );
						$content['subtitle'] 	= $join_team_subtitle;
						$content['description'] = tp_philosophy_pro_trim_content( 65, $join_page );
						$content['blockquote']  = $join_team_blockquote;
	                }
                    break;

                    case 'custom' :
                    	$content['img_array']   = array ( $join_background_image );
						$content['url']         = $join_custom_url;
						$content['title']       = $join_team_title;
						$content['subtitle'] 	= $join_team_subtitle;
						$content['description'] = $join_team_description;
						$content['blockquote']  = $join_team_blockquote;
                    	break;

                default :
                    break;
            }

            if( ! empty( $content ) ) {
            	$input = $content;
            }
            // pre_dump( $input );
            return $input;
        }
    endif;
    add_filter ( 'tp_philosophy_pro_filter_join_team_options', 'tp_philosophy_pro_filter_get_join_team_options' );

	if( ! function_exists( 'tp_philosophy_pro_render_join_team_section' ) ) :
    	/**
    	 * Render join team section 
    	 * 
    	 * @since 1.0
    	 */

    	function tp_philosophy_pro_render_join_team_section() {
    		$options = tp_philosophy_pro_get_theme_options(); // get theme options

    		$enable_join_team_section = isset( $options['enable_join_team_section'] ) ? $options['enable_join_team_section'] : false;

		    if( false == $enable_join_team_section ) {
		    	return false;
		    }

		    $content_detail = array();
		    $content_detail = apply_filters( 'tp_philosophy_pro_filter_join_team_options', $content_detail );

            $heading_box_layout = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border' : '';
    		?>

	    	<section id="join" class="col-2 page-section">
		        <div class="wrapper">
		          	<div class="column-wrapper">
			            <header class="entry-header <?php echo esc_attr( $heading_box_layout ); ?> border-small">
			            	<?php
			            		if ( !empty( $content_detail['title'] ) ) {
			            			echo '<h2 class="entry-title">'. esc_html( $content_detail['title'] ) .'</h2>';
			            		}

			            		if ( !empty( $content_detail['subtitle'] ) ) {
			            			echo '<h3 class="sub-title">'. esc_html( $content_detail['subtitle'] ) .'</h3>';
			            		}
			            	?>
			              	
			            </header><!-- .entry-header-->
			            <div class="entry-content">
			            	<?php 
			            		if ( !empty( $content_detail['description'] ) ) {
			            			echo '<p>'. esc_html( $content_detail['description'] ) .'</p>';
			            		}

			            		if ( !empty( $content_detail['blockquote'] ) ) {
			            			echo '<blockquote>'. wp_kses_data( $content_detail['blockquote'] ) .'</blockquote>';
			            		}
			            	?>
			            </div><!-- .entry-content-->
		          	</div><!--.column-wrapper-->
		          	<?php if ( !empty( $content_detail['img_array'] ) ) : ?>
			          	<div class="column-wrapper">
				            <div class="featured-image">
				              	<a href="<?php echo esc_url( $content_detail['url'] ); ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>"></a>
				            </div>
			          	</div><!--.column-wrapper-->
		          	<?php endif; ?>
		        </div><!--.wrapper-->
      		</section>

		<?php 
    	} 
	endif;

	add_action( 'tp_philosophy_pro_teams_options', 'tp_philosophy_pro_render_join_team_section', 20 );

	do_action( 'tp_philosophy_pro_teams_options' ); // render team options
    get_footer();