<?php
/**
 * TP Philosophy Pro Blogs Customizer options
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

// Add Blogs section enable option
$wp_customize->add_section( 'tp_philosophy_pro_blogs_section', array(
	'title'             => esc_html__( 'Blogs Section', 'tp-philosophy-pro' ),
	'description'       => esc_html__( 'Blogs section options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_homepage_sections_panel'
) );

// Add category blog enable setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[blogs_enable]', array(
	'default'           => $options['blogs_enable'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[blogs_enable]', array(
	'label'             => esc_html__( 'Enable on', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_blogs_section',
	'type'              => 'select',
	'choices'           => tp_philosophy_pro_enable_disable_options()
) );

// Add category blog content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[blogs_content_type]', array(
	'default'           => $options['blogs_content_type'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[blogs_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_blogs_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'tp_philosophy_pro_is_blogs_active',
	'choices'         	=> array(
		'demo'     		=> esc_html__( 'Demo', 'tp-philosophy-pro' ),
        'posts'    		=> esc_html__( 'Posts', 'tp-philosophy-pro' ),
        'category' 		=> esc_html__( 'Category', 'tp-philosophy-pro' ),
    ),
) );

// Add blogs section title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[blogs_title]',array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'           => $options['blogs_title'],
	'transport' 		=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'tp_philosophy_pro_theme_options[blogs_title]', array(
		'selector'            => '#blog h2.entry-title',
		'render_callback'     => 'philisophy_pro_blogs_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[blogs_title]',array(
	'label'           	=> esc_html__( 'Title', 'tp-philosophy-pro' ),
	'description'     	=> esc_html__( 'Enter Title.', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_blogs_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_blogs_content_demo_inactive',
) );

// Add blogs section sub title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[blogs_subtitle]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default' 			=> $options['blogs_subtitle'],
	'transport' 		=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'tp_philosophy_pro_theme_options[blogs_subtitle]', array(
		'selector'            => '#blog h3.sub-title',
		'render_callback'     => 'philisophy_pro_blogs_subtitle_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[blogs_subtitle]', array(
	'label'      		=> esc_html__( 'Subtitle', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Enter subtitle.', 'tp-philosophy-pro' ),
	'section'    		=> 'tp_philosophy_pro_blogs_section',
    'active_callback'	=> 'tp_philosophy_pro_is_blogs_content_demo_inactive',
) );

for( $i=1; $i<=4; $i++ ){
	/**
 	 * Content type: post
	 */ 
	
	// Add setting and controls to input post id

	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[blogs_content_posts_'. $i .']', array(
		'sanitize_callback' => 'tp_philosophy_pro_sanitize_number_range',
	) );

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[blogs_content_posts_'. $i .']', array(
		'label'           => sprintf( esc_html__( 'Enter Post ID #%s', 'tp-philosophy-pro' ), $i ),
		'section'         => 'tp_philosophy_pro_blogs_section',
		'input_attrs'     => array( 
			'style'       => 'width: 100px;',
			'min'         => '1', 
			'placeholder' => esc_attr__( 'Post ID', 'tp-philosophy-pro' ) 
		),
		'type'            => 'number',
		'active_callback' => 'tp_philosophy_pro_blogs_content_post_active',
	) );
}

// Add Category Content Type
$wp_customize->add_setting(  'tp_philosophy_pro_theme_options[blogs_content_category]', array(
  	'sanitize_callback' => 'tp_philosophy_pro_sanitize_muti_select_categories_list',
) ) ;

$wp_customize->add_control( new Tp_Philosophy_Pro_Multi_Select_Categories_Control ( $wp_customize,'tp_philosophy_pro_theme_options[blogs_content_category]', array(
	'label'             => esc_html__( 'Select Categories', 'tp-philosophy-pro' ),
	'description' 		=> esc_html__( 'Select categories for blog section', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_blogs_section',
	'active_callback'   => 'tp_philosophy_pro_blogs_content_category_active'
) ) );