<?php
/**
 * TP Philosophy Pro services section customizer options
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

// Add services section
$wp_customize->add_section( 'tp_philosophy_pro_services_section', 
	array(
		'title'             => esc_html__( 'Services','tp-philosophy-pro' ),
		'description'       => esc_html__( 'services section options.', 'tp-philosophy-pro' ),
		'panel'             => 'tp_philosophy_pro_homepage_sections_panel',
	)
);

// Add services section enable setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_enable]', 
	array(
		'default'           => $options['services_enable'],
		'sanitize_callback' => 'tp_philosophy_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_enable]', 
	array(
		'label'             => esc_html__( 'Enable on', 'tp-philosophy-pro' ),
		'section'           => 'tp_philosophy_pro_services_section',
		'type'              => 'select',
		'choices'           => tp_philosophy_pro_enable_disable_options(),
	)
);

// Add services heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_left_section]', array(
	'sanitize_callback' 	=> 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[services_left_section]', 
	array(
		'label'           	=> esc_html__( 'Services Left Section', 'tp-philosophy-pro' ),
		'section'         	=> 'tp_philosophy_pro_services_section',
		'type'				=> 'description',
		'active_callback' 	=> 'tp_philosophy_pro_is_services_enable',
	)
) );

// Add services left section content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_left_content_type]', 
	array(
		'default'           => $options['services_left_content_type'],
		'sanitize_callback' => 'tp_philosophy_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_left_content_type]', 
	array(
		'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
		'section'         	=> 'tp_philosophy_pro_services_section',
		'type'            	=> 'select',
		'active_callback' 	=> 'tp_philosophy_pro_is_services_enable',
		'choices'         	=> array(
			'demo'     		=> esc_html__( 'Demo', 'tp-philosophy-pro' ),
			'posts'    		=> esc_html__( 'Posts', 'tp-philosophy-pro' ),
			'pages'    		=> esc_html__( 'Pages', 'tp-philosophy-pro' ),
			'custom'   		=> esc_html__( 'Custom', 'tp-philosophy-pro' ),
	    ),
	)
);

// Add setting and controls to input post id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_post_id]', 
	array(
		'sanitize_callback' => 'tp_philosophy_pro_sanitize_number_range',
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_post_id]', 
	array(
		'label'           	=> esc_html__( 'Enter Post ID', 'tp-philosophy-pro' ),
		'section'         	=> 'tp_philosophy_pro_services_section',
		'input_attrs' 		=> array( 
			'style' 		=> 'width: 100px;',
			'min'			=> '1', 
			'placeholder'	=> esc_attr__( 'Post ID', 'tp-philosophy-pro' ) ),
		'type'              => 'number',
		'active_callback' 	=> 'tp_philosophy_pro_is_services_left_content_post_active',
	)
);

// Add setting and controls to input page id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_page_id]', 
	array(
		'sanitize_callback' => 'tp_philosophy_pro_sanitize_page'
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_page_id]', 
	array(
		'label'             => esc_html__( 'Select Page' , 'tp-philosophy-pro' ),
		'section'           => 'tp_philosophy_pro_services_section',
		'active_callback'	=> 'tp_philosophy_pro_is_services_left_content_page_active',
		'type'              => 'dropdown-pages',
	)
);

// Add services section custom title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_custom_title]',array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['services_custom_title'],
		'transport' 		=> 'postMessage',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'tp_philosophy_pro_theme_options[services_custom_title]', 
		array(
		'selector'            => '#services h2.entry-title',
		'render_callback'     => 'philisophy_pro_services_custom_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		)
	);
}

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_custom_title]',array(
		'label'           	=> esc_html__( 'Title', 'tp-philosophy-pro' ),
		'description'     	=> esc_html__( 'Enter Title.', 'tp-philosophy-pro' ),
		'section'         	=> 'tp_philosophy_pro_services_section',
		'active_callback' 	=> 'tp_philosophy_pro_is_services_left_content_custom_active',
	)
);

// Add services section sub title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_subtitle]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['services_subtitle'],
		'transport' 		=> 'postMessage',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'tp_philosophy_pro_theme_options[services_subtitle]', array(
		'selector'            => '#services h3.sub-title',
		'render_callback'     => 'philisophy_pro_services_subtitle_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_subtitle]',
	array(
		'label'           	=> esc_html__( 'Subtitle', 'tp-philosophy-pro' ),
		'description'     	=> esc_html__( 'Enter subtitle.', 'tp-philosophy-pro' ),
		'section'         	=> 'tp_philosophy_pro_services_section',
		'active_callback' 	=> 'tp_philosophy_pro_is_services_left_content_demo_inactive',
	)
);

// Add services section custom description
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_custom_description]',
	array(
		'sanitize_callback' => 'esc_textarea',
		'default'           => $options['services_custom_description'],
		'transport' 		=> 'postMessage',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'tp_philosophy_pro_theme_options[services_custom_description]', array(
		'selector'            => '#services .entry-content p',
		'render_callback'     => 'philisophy_pro_services_custom_description_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_custom_description]',
    array(
		'label'           	=> esc_html__( 'Description', 'tp-philosophy-pro' ),
		'description'     	=> esc_html__( 'Input description.', 'tp-philosophy-pro' ),
		'section'         	=> 'tp_philosophy_pro_services_section',
		'type'            	=> 'textarea',
		'active_callback' 	=> 'tp_philosophy_pro_is_services_left_content_custom_active',
    )
);

// Add learn more text
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_learn_more_text]',array(
		'sanitize_callback' 	=> 'sanitize_text_field',
		'default'           	=> $options['services_learn_more_text'],
		'transport' 			=> 'postMessage',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'tp_philosophy_pro_theme_options[services_learn_more_text]', array(
		'selector'            => '#services a.view-more',
		'render_callback'     => 'philisophy_pro_services_learn_more_text_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_learn_more_text]',array(
		'label'           => esc_html__( 'Learn More Text', 'tp-philosophy-pro' ),
		'description'     => esc_html__( 'Enter learn more text.', 'tp-philosophy-pro' ),
		'section'         => 'tp_philosophy_pro_services_section',
		'active_callback' => 'tp_philosophy_pro_is_services_left_content_demo_inactive',
	)
);

// Add learn more custom link setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_custom_link]', array(
	'default'           => $options['services_custom_link'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_custom_link]', array(
	'label'           	=> esc_html__( 'Link', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Input link', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_services_section',
	'type'				=> 'url',
	'active_callback' 	=> 'tp_philosophy_pro_is_services_left_content_custom_active',
) );

// Add custom image setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_custom_image]', array(
	'default'           => $options['services_custom_image'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tp_philosophy_pro_theme_options[services_custom_image]',
    array(
		'label'           => esc_html__( 'background image', 'tp-philosophy-pro' ),
		'description'     => esc_html__( 'Recommended background image size is 450x515 px', 'tp-philosophy-pro' ),
		'section'         => 'tp_philosophy_pro_services_section',
		'active_callback' => 'tp_philosophy_pro_is_services_left_content_demo_inactive',
   )
) );

/**
 * Services listing
 */

// Add services control options heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_right_section]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[services_right_section]', array(
	'label'           	=> esc_html__( 'Services Right Section', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_services_section',
	'type'				=> 'description',
	'active_callback' 	=> 'tp_philosophy_pro_is_services_enable',
) ) );

// Add services right section content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_right_content_type]', array(
	'default'           => $options['services_right_content_type'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[services_right_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_services_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'tp_philosophy_pro_is_services_enable',
	'choices'         	=> array(
		'demo'     		=> esc_html__( 'Demo', 'tp-philosophy-pro' ),
		'posts'    		=> esc_html__( 'Posts', 'tp-philosophy-pro' ),
		'custom'   		=> esc_html__( 'Custom', 'tp-philosophy-pro' ),
    ),
) );

for ( $i= 1; $i <= 4; $i++ ){

	// Add setting and controls to input post id
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[featured_service_post_id_'. $i .']', array(
		'sanitize_callback' => 'tp_philosophy_pro_sanitize_number_range',
	) );

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[featured_service_post_id_'. $i .']', 
		array(
			'label'           => sprintf( esc_html__( 'Service Post ID %s', 'tp-philosophy-pro' ), $i ),
			'section'         => 'tp_philosophy_pro_services_section',
			'input_attrs'     => array( 
				'style'       => 'width: 100px;',
				'min'         => '1', 
				'placeholder' => esc_attr__( 'Post ID', 'tp-philosophy-pro' ),
			),
			'type'            => 'number',
			'active_callback' => 'tp_philosophy_pro_is_services_right_content_post_active',
		)
	);

	// Add learn more text setting and control.
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[featured_service_title_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[featured_service_title_'. $i .']', 
		array(
			'label'           => sprintf( esc_html__( 'Featured Service Title %1$s', 'tp-philosophy-pro' ), $i ),
			'description'     => esc_html__( 'Input featured service title.', 'tp-philosophy-pro' ),
			'section'         => 'tp_philosophy_pro_services_section',
			'active_callback' => 'tp_philosophy_pro_is_services_right_content_custom_active',
		)
	);

	// Add font awesome icon setting and control.
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[featured_service_icon_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[featured_service_icon_'. $i .']', array(
		'label'           	=> sprintf( esc_html__( 'Font icon %s', 'tp-philosophy-pro' ), $i ),
		'description'		=> sprintf( '%1$s <a target="_blank" href="%2$s">%3$s</a>.', esc_html__( 'Example fa-cloud-upload see more at', 'tp-philosophy-pro' ) , esc_url( 'http://fontawesome.io/icons/' ), esc_html__( 'Font Awesome', 'tp-philosophy-pro' ) ),
		'section'         	=> 'tp_philosophy_pro_services_section',
		'input_attrs'     	=> array( 
			'placeholder' 	=> esc_attr__( 'fa-user', 'tp-philosophy-pro' ),
		),
		'active_callback' 	=> 'tp_philosophy_pro_is_services_right_content_demo_inactive',
	) );

	// Add featured service description
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[featured_service_description_'. $i .']',
		array(
			'sanitize_callback'	=> 'esc_textarea',
		)
	);

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[featured_service_description_'. $i .']',
	    array(
			'label'           => sprintf( esc_html__( 'Service Description %s', 'tp-philosophy-pro' ), $i ),
			'description'     => esc_html__( 'Input description.', 'tp-philosophy-pro' ),
			'section'         => 'tp_philosophy_pro_services_section',
			'type'            => 'textarea',
			'active_callback' => 'tp_philosophy_pro_is_services_right_content_custom_active',
	    )
	);

	// Add horizontol line  setting and control.
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[featured_service_hr_line_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Tp_Philosophy_Pro_Customize_Horizontal_Line( $wp_customize, 'tp_philosophy_pro_theme_options[featured_service_hr_line_'. $i .']',
	    array(
			'section'         => 'tp_philosophy_pro_services_section',
			'type'			  => 'hr',
			'active_callback' => 'tp_philosophy_pro_is_services_right_content_demo_inactive',
	   )
	));
}

// Add services background image setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[services_background_image]', array(
	'default'           => $options['services_background_image'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tp_philosophy_pro_theme_options[services_background_image]',
    array(
		'label'           => esc_html__( 'Upload Services Background Image', 'tp-philosophy-pro' ),
		'description'     => esc_html__( 'Recommended slide image size is 862x722 px', 'tp-philosophy-pro' ),
		'section'         => 'tp_philosophy_pro_services_section',
		'active_callback' => 'tp_philosophy_pro_is_services_right_content_demo_inactive',
   	)
) );