<?php
/**
 * TP Philosophy Pro team customizer options
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

// Add teams section
$wp_customize->add_section( 'tp_philosophy_pro_teams_section', array(
	'title'             => esc_html__( 'Teams','tp-philosophy-pro' ),
	'description'       => esc_html__( 'Teams section options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_homepage_sections_panel'
) );

// Add teams section enable setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[teams_enable]', array(
	'default'           => $options['teams_enable'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[teams_enable]', array(
	'label'             => esc_html__( 'Enable on', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_teams_section',
	'type'              => 'select',
	'choices'           => tp_philosophy_pro_enable_disable_options()
) );

if ( ! class_exists( 'TP_Philosophy_Tools' ) ) {
    $content_type_description = esc_html__( 'Team section requires', 'tp-philosophy-pro' ) . sprintf( '<a target="_blank" href="%s"> %s </a>', esc_url( 'https://wordpress.org/plugins/tp-philosophy-teams/' ), esc_html__( 'TP Philosophy Tools Plugin', 'tp-philosophy-pro' ) );

	$choices = array(
		'demo'                => esc_html__( 'Demo', 'tp-philosophy-pro' ),
		'posts'               => esc_html__( 'Posts', 'tp-philosophy-pro' ),
	);
} else{
    $content_type_description = '';
    $choices = array(
		'demo'                => esc_html__( 'Demo', 'tp-philosophy-pro' ),
		'posts'               => esc_html__( 'Posts', 'tp-philosophy-pro' ),
		'tp-philosophy-teams' => esc_html__( 'Teams', 'tp-philosophy-pro' ),
	);
    
}

// Add teams section content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[teams_content_type]', array(
	'default'           => $options['teams_content_type'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[teams_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'description' 		=> $content_type_description,
	'section'         	=> 'tp_philosophy_pro_teams_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'tp_philosophy_pro_is_teams_enable',
	'choices'         	=> $choices,
) );

// Add teams custom title setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[teams_custom_title]', array(
	'default'           => $options['teams_custom_title'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[teams_custom_title]', array(
	'label'           	=> esc_html__( 'Title', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Input title', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_teams_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_teams_demo_inactive',
) );

// Add teams custom subtitle setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[teams_custom_subtitle]', array(
	'default'           => $options['teams_custom_subtitle'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[teams_custom_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Input subtitle', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_teams_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_teams_demo_inactive',
) );

// Add teams custom description setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[teams_custom_description]', array(
	'default'           => $options['teams_custom_description'],
	'sanitize_callback' => 'esc_textarea',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[teams_custom_description]', array(
	'label'           	=> esc_html__( 'Description', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Input description', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_teams_section',
	'type'				=> 'textarea',
	'active_callback' 	=> 'tp_philosophy_pro_is_teams_demo_inactive',
) );

// Add teams section number of posts setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[teams_no_of_slides]', array(
	'default'           => $options['teams_no_of_slides'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[teams_no_of_slides]', array(
	'label'           	=> esc_html__( 'Number Of Slides', 'tp-philosophy-pro' ),
	'description'       => esc_html__( 'Notice: Min vaue is  5 and max value is 10', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_teams_section',
	'type'            	=> 'number',
	'input_attrs'		=> array(
		'min'			=> '5',
		'max'			=> '10',
		'step'			=> '1',
		'style'			=> 'width:50px',
	),
	'active_callback' 	=> 'tp_philosophy_pro_is_teams_demo_inactive',
) );

// Add setting and controls to input post id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[teams_post_ids]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[teams_post_ids]', array(
	'label'           => esc_html__( 'Team member', 'tp-philosophy-pro' ),
	'description' 	  => esc_html__( 'Enter post ID seperated with comma. Example 88,91,93', 'tp-philosophy-pro' ),
	'section'         => 'tp_philosophy_pro_teams_section',
	'active_callback' => 'tp_philosophy_pro_is_teams_content_post_active',
) );

// Add setting and controls to input post id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[cpt_teams_post_ids]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[cpt_teams_post_ids]', array(
	'label'           => esc_html__( 'Cpt Team member', 'tp-philosophy-pro' ),
	'description' 	  => esc_html__( 'Enter post ID seperated with comma. Example 88,91,93', 'tp-philosophy-pro' ),
	'section'         => 'tp_philosophy_pro_teams_section',
	'active_callback' => 'tp_philosophy_pro_is_cpt_teams_content_post_active',
) );