<?php
/**
 * Skills section
 *
 * This is the template for the content of skills section
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

if ( ! function_exists( 'tp_philosophy_pro_add_skills_section' ) ) :
    /**
    * Add skills section
    *
    * @since 1.0
    */

    function tp_philosophy_pro_add_skills_section() {

        // Check if skills section is enabled on frontpage
        $skills_section_enable = apply_filters( 'tp_philosophy_pro_section_status', true, 'skills_enable' );
        if ( true !== $skills_section_enable ) {
            return false;
        }

        // Get skills section details
        $section_details = array();
        $section_details = apply_filters( 'tp_philosophy_pro_filter_skills_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render skills section now.
        tp_philosophy_pro_render_skills_section( $section_details );
    }
endif;
add_action( 'tp_philosophy_pro_homepage_section', 'tp_philosophy_pro_add_skills_section', 40 );

if ( ! function_exists( 'tp_philosophy_pro_get_skills_section_details' ) ) :
    /**
     * Skills section details.
     *
     * @since 1.0
     * @param array $input Skills section details.
     */

    function tp_philosophy_pro_get_skills_section_details( $input ) {
        $options = tp_philosophy_pro_get_theme_options(); // Get theme options

        // Skills section options
        $skills_content_type     = $options['skills_content_type'];
        $skills_subtitle         = !empty( $options['skills_subtitle'] ) ? $options['skills_subtitle'] : '';
        $graph_shortcode         = !empty( $options['skills_graph_shortcode'] ) ? $options['skills_graph_shortcode'] : ''; 
        
        $content = array();
        switch ( $skills_content_type ) {
            case 'demo':
                $content['title']               = esc_html__( 'SKILLS', 'tp-philosophy-pro' );
                $content['subtitle']            = esc_html__( 'OUR EXCELLENCE.', 'tp-philosophy-pro' );
                $content['description']         = esc_html__( 'Sed congue cursus quam quis fermentum. Nullam augue risus, molestie non est non, elementum tristique ex. Fusce vel magna est. Praesent in eleifend nulla, et sagittis leo. Nunc feugiat semper tellus. Cras justo sapien, imperdiet eu fringilla eu, accumsan a sem. Nunc venenatis felis metus, quis cursus massa gravida vel. Suspendisse potenti. Morbi sollicitudin eu nisl quis venenatis. Donec ultrices posuere quam sit amet tincidunt. Mauris feugiat mattis scelerisque. Suspendisse euismod sapien vitae pharetra dictum.', 'tp-philosophy-pro' );
                
                $content['skills_background'][0] = get_template_directory_uri() . '/assets/uploads/skill-bg.jpg';

                $content['graph_shortcode'] = '[TP_PIEBUILDER_BAR values="97, 64, 70, 75, 62" labels="Design, Html/Css, Php coding, Planning, Management" colors="#f7c84a, #64d4f9, #64d4f9, #ff5c5c, #745fa4"]';
            break;

            case 'posts':
                $post_id = !empty ( $options['skills_post_id'] ) ? absint( $options['skills_post_id'] ) : '';

                if( empty( $post_id  ) ) return $input; // Return if post id is empty

                $skills_post = get_post( $post_id ); // Get service post
                
                $content['title']             = get_the_title( $skills_post->ID );
                $content['subtitle']          = $skills_subtitle;
                $content['description']       = tp_philosophy_pro_trim_content( 55, $skills_post );
                
                
                if( has_post_thumbnail( $skills_post->ID ) ){
                    $content['skills_background'] = wp_get_attachment_image_src( get_post_thumbnail_id( $skills_post->ID ), 'tp-philosophy-pro-services-thumbnail' );
                } else {
                    $content['skills_background'][0] = get_template_directory_uri().'/assets/uploads/no-featured-image-1070x925.jpg';
                }

                $content['graph_shortcode'] = $graph_shortcode;
            break;
            
            case 'pages':
                $page_id = !empty ( $options['skills_page_id'] ) ? absint( $options['skills_page_id'] ) : '';

                if( empty( $page_id  ) ) return $input; // Return if post id is empty

                $skills_page = get_post( $page_id ); // Get service post

                $content['title']               = get_the_title( $skills_page->ID );
                $content['subtitle']            = $skills_subtitle;
                $content['description']         = tp_philosophy_pro_trim_content( 55, $skills_page );
                
                if( has_post_thumbnail( $skills_page->ID ) ){
                    $content['skills_background'] = wp_get_attachment_image_src( get_post_thumbnail_id( $skills_page->ID ), 'tp-philosophy-pro-services-thumbnail' );
                } else {
                    $content['skills_background'][0] = get_template_directory_uri().'/assets/uploads/no-featured-image-1070x925.jpg';
                }

            break; 

            case 'custom':
                $content['title']               = !empty( $options['skills_custom_title'] ) ? $options['skills_custom_title'] : '';
                $content['subtitle']            = $skills_subtitle;
                $content['description']         = !empty( $options['skills_custom_description'] ) ? $options['skills_custom_description'] : '';
                
                $content['skills_background'][0] = !empty( $options['skills_custom_image'] ) ? $options['skills_custom_image'] : '';
                $content['graph_shortcode'] = $graph_shortcode;

            break;

            default:
            break;
        }
                                                                                                                   
        if ( !empty( $content ) ) {
            $input = $content;
        }
        return $input;
      }
endif;

// Skills section content details.
add_filter( 'tp_philosophy_pro_filter_skills_details', 'tp_philosophy_pro_get_skills_section_details' );

if ( ! function_exists( 'tp_philosophy_pro_render_skills_section' ) ) :
    /**
     * Start skills section
     *
     * @return string skills section content
     * @since 1.0
     *
     */
    function tp_philosophy_pro_render_skills_section( $content ) { 

        $options = tp_philosophy_pro_get_theme_options(); // get theme options
        $heading_box_layout = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border' : '';

        // Get skills background inline css
        if( !empty( $content['skills_background'] ) ){
            $skills_background_inline_css = "style='background-image: url(".esc_url( $content['skills_background'][0] ) .");'";
        }else{
            $skills_background_inline_css = '';
        }

        ?>
        <section id="skill" class="col-2 page-section" <?php echo $skills_background_inline_css; ?>>
            <div class="wrapper">
                <div class="row">
                    <div class="column-wrapper">

                        <?php if( !empty( $content['title'] ) || !empty( $content['subtitle'] ) ) : ?>
                            <header class="entry-header <?php echo esc_attr( $heading_box_layout ); ?>">
                                <?php 
                                    if( !empty( $content['title'] ) ) {
                                        echo '<h2 class="entry-title color-white">'. esc_html( $content['title'] ) .'</h2>'; 
                                    }

                                    if( !empty( $content['subtitle'] ) ){
                                        echo '<h3 class="sub-title">'. esc_html( $content['subtitle'] ) .'</h3>';
                                    }
                                ?>                                
                            </header><!--.entry-header-->
                        <?php endif; 

                            if( !empty( $content['description'] ) ){
                                echo '<div class="entry-content"><p>'. esc_html( $content['description'] ) .'</p></div>';
                            }
                        ?>
                    </div><!--.column-wrapper-->

                    <?php if( !empty( $content['graph_shortcode'] ) ) : ?>
                        <div class="column-wrapper">
                            <?php echo do_shortcode( $content['graph_shortcode'] ); ?>                            
                        </div><!--.column-wrapper-->
                    <?php endif; ?>
                </div><!--.row-->
            </div><!-- .wrapper -->
        </section><!-- #skill-->
        <?php 
    }
endif;